# webKnossos REST-API client

:warning: Most code of this client is auto-generated! Please don't adapt anything in the `generated` folder manually, but re-run the code generation.

The client code is generated using [openapi-python-client](https://github.com/openapi-generators/openapi-python-client) and [InducOapi](https://github.com/TheWall89/inducoapi).

To re-generate, run
```bash
poetry run python __generate_client.py
```
